OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan ikke skrive til mappen \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Dette kan normalt rettes ved at give webserveren skriveadgang til config folderen.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Men hvis du foretrækker at bibeholde config.php skrivebeskyttet, så sæt parameter \"config_is_read_only\" til true i filen. ",
    "See %s" : "Se %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Applikationen %1$s er ikke til stede eller har en ikke-kompatibel version med denne server. Tjek venligst apps mappen.",
    "Sample configuration detected" : "Eksempel for konfiguration registreret",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Der er registreret at konfigurations eksemplet er blevet kopieret direkte. Dette kan ødelægge din installation og understøttes ikke. Læs venligst dokumentationen før der foretages ændringer i config.php",
    "The page could not be found on the server." : "Siden kunne ikke findes på serveren.",
    "%s email verification" : "%s email verifikation",
    "Email verification" : "Email verifikation",
    "Click the following button to confirm your email." : "Tryk på følgende knap for at bekræfte din email.",
    "Click the following link to confirm your email." : "Klik på følgende link for at bekræfte din email.",
    "Confirm your email" : "Bekræft din email",
    "Other activities" : "Andre aktiviteter",
    "%1$s and %2$s" : "%1$s og %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s og %5$s",
    "Education Edition" : "Education Edition",
    "Enterprise bundle" : "Enterprise bundle",
    "Groupware bundle" : "Groupware bundle",
    "Hub bundle" : "Hub bundle",
    "Social sharing bundle" : "Social sharing bundle",
    "PHP %s or higher is required." : "Der kræves PHP %s eller nyere.",
    "PHP with a version lower than %s is required." : "Der kræves PHP %s eller ældre.",
    "%sbit or higher PHP required." : "Der kræves PHP %s eller nyere.",
    "The following architectures are supported: %s" : "Følgende arkitekturer er understøttes: %s",
    "The following databases are supported: %s" : "Følgende databaser understøttes: %s",
    "The command line tool %s could not be found" : "Kommandolinjeværktøjet %s blev ikke fundet",
    "The library %s is not available." : "Biblioteket %s er ikke tilgængeligt.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Der kræves en version af biblioteket %1$s, der er højere end %2$s - tilgængelig version er %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Der kræves en version af biblioteket %1$s, der er lavere end %2$s - tilgængelig version er %3$s.",
    "The following platforms are supported: %s" : "Følgende platforme understøttes: %s",
    "Server version %s or higher is required." : "Du skal have server version %s eller nyere.",
    "Server version %s or lower is required." : "Du skal have server version %s eller ældre.",
    "Wiping of device %s has started" : "Komplet sletning af enhed %s er påbegyndt",
    "Wiping of device »%s« has started" : "Komplet sletning af enhed »%s« er påbegyndt",
    "»%s« started remote wipe" : "Fjernsletning påbegyndt af »%s« ",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Enheden eller applikationen  »%s« har påbegyndt en fjernsletnings proces. Du vil modtage en e-mail når processen er færdig",
    "Wiping of device %s has finished" : "Komplet sletning af enhed %s er færdig",
    "Wiping of device »%s« has finished" : "Komplet sletning af enhed »%s« er færdig",
    "»%s« finished remote wipe" : "»%s« er færdig med fjernsletning",
    "Device or application »%s« has finished the remote wipe process." : " Fjernsletningen der blev aktiveret af enhed alle applikation »%s« er færdig.",
    "Remote wipe started" : "Fjernsletning er startet",
    "A remote wipe was started on device %s" : "En fjernsletning af enheden %s er påbegyndt",
    "Remote wipe finished" : "Fjernsletning er færdig",
    "The remote wipe on %s has finished" : "Fjernsletningen af %s er færdig",
    "Authentication" : "Godkendelse",
    "Unknown filetype" : "Ukendt filtype",
    "Invalid image" : "Ugyldigt billede",
    "Avatar image is not square" : "Avatar billedet er ikke kvadratisk",
    "Files" : "Filer",
    "View profile" : "Vis profil",
    "Local time: %s" : "Lokal tid: %s",
    "today" : "i dag",
    "tomorrow" : "i morgen",
    "yesterday" : "i går",
    "_in %n day_::_in %n days_" : ["om %n dag","om %n dage"],
    "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dage siden"],
    "next month" : "næste måned",
    "last month" : "sidste måned",
    "_in %n month_::_in %n months_" : ["om %n måned","om %n måneder"],
    "_%n month ago_::_%n months ago_" : ["%n måned siden","%n måneder siden"],
    "next year" : "næste år",
    "last year" : "sidste år",
    "_in %n year_::_in %n years_" : ["om %n år","om %n år"],
    "_%n year ago_::_%n years ago_" : ["%n år siden","%n år siden"],
    "_in %n hour_::_in %n hours_" : ["om %n time","om %n timer"],
    "_%n hour ago_::_%n hours ago_" : ["%n time siden","%n timer siden"],
    "_in %n minute_::_in %n minutes_" : ["om %n minut","om %n minutter"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minut siden","%n minutter siden"],
    "in a few seconds" : "om få sekunder",
    "seconds ago" : "få sekunder siden",
    "Empty file" : "Tom fil",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulet med ID: %s eksisterer ikke. Aktiver det venligst i dine indstillinger eller kontakt din administrator.",
    "File already exists" : "Filen findes allerede",
    "Invalid path" : "Ugyldig sti",
    "Failed to create file from template" : "Fejl ved oprettelse af fil fra skabelon",
    "Templates" : "Skabeloner",
    "File name is a reserved word" : "Filnavnet er et reserveret ord",
    "File name contains at least one invalid character" : "Filnavnet indeholder mindst ét ugyldigt tegn",
    "File name is too long" : "Filnavnet er for langt",
    "Dot files are not allowed" : "Filer med punktummer er ikke tilladt",
    "Empty filename is not allowed" : "Tomme filnavne er ikke tilladt",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan ikke installeres fordi appinfo filen ikke kan læses.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan ikke installeres fordi den ikke er kompatibel med denne version af serveren.",
    "__language_name__" : "Dansk",
    "This is an automatically sent email, please do not reply." : "Dette er en automatisk sendt e-mail, svar venligst ikke.",
    "Help" : "Hjælp",
    "Appearance and accessibility" : "Udseende og tilgængelighed",
    "Apps" : "Apps",
    "Personal settings" : "Personlige indstillinger",
    "Administration settings" : "System indstillinger",
    "Settings" : "Indstillinger",
    "Log out" : "Log ud",
    "Users" : "Brugere",
    "Email" : "E-mail",
    "Mail %s" : "Mail %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Vis %s på fediverset",
    "Phone" : "Telefon",
    "Call %s" : "Ring op %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Følg %s på Twitter",
    "Website" : "Hjemmeside",
    "Visit %s" : "Besøg %s",
    "Address" : "Adresse",
    "Profile picture" : "Profilbillede",
    "About" : "Om",
    "Display name" : "Vist navn",
    "Headline" : "Overskrift",
    "Organisation" : "Organisation",
    "Role" : "Rolle",
    "Additional settings" : "Yderligere indstillinger",
    "Enter the database name for %s" : "Indtast databasenavnet for %s",
    "You cannot use dots in the database name %s" : "Du må ikke bruge punktummer i databasenavnet %s",
    "You need to enter details of an existing account." : "Du skal indtaste detaljerne for en eksisterende konto.",
    "Oracle connection could not be established" : "Oracle forbindelsen kunne ikke etableres",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X understøttes ikke og %s vil ikke virke optimalt på denne platform. Anvend på eget ansvar!",
    "For the best results, please consider using a GNU/Linux server instead." : "For de bedste resultater, overvej venligst at bruge en GNU/Linux-server i stedet.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ud til, at denne %s-instans kører på et 32-bit PHP-miljø, samt at open_basedir er blevet konfigureret gennem php.ini. Dette vil føre til problemer med filer som er større end 4GB, og frarådes kraftigt.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern venligst indstillingen for open_basedir inde i din php.ini eller skift til 64-bit PHP.",
    "Set an admin password." : "Angiv et admin kodeord.",
    "Cannot create or write into the data directory %s" : "Kan ikke oprette eller skrive ind i datamappen %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delingsbackend'en %s skal implementere grænsefladen OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delingsbackend'en %s blev ikke fundet",
    "Sharing backend for %s not found" : "Delingsbackend'en for %s blev ikke fundet",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delte »%2$s« med dig og vil gerne tilføje:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s delte »%2$s« med dig og vil gerne tilføje",
    "»%s« added a note to a file shared with you" : "»%s« tilføjede en note til en fil delt med dig",
    "Open »%s«" : "Åbn »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "You are not allowed to share %s" : "Du har ikke tilladelse til at dele %s",
    "Cannot increase permissions of %s" : "Kan give yderigere rettigheder til %s",
    "Files cannot be shared with delete permissions" : "Filer kan ikke deles med rettigheder til at slette",
    "Files cannot be shared with create permissions" : "Filer kan ikke deles med rettigheder til at oprette",
    "Expiration date is in the past" : "Udløbsdatoen ligger tilbage i tid",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Udløbsdato kan ikke sættes mere end %n dag ud i fremtiden","Udløbsdato kan ikke sættes mere end %n dage ud i fremtiden"],
    "Sharing is only allowed with group members" : "Deling er kun tilladt med gruppemedlemmer",
    "%1$s shared »%2$s« with you" : "%1$s delte »%2$s« med dig",
    "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med dig",
    "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
    "The requested share does not exist anymore" : "Det delte emne eksisterer ikke længere",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Brugeren blev ikke oprettet, fordi brugergrænsen er nået. Tjek dine notifikationer for at få flere oplysninger.",
    "Could not find category \"%s\"" : "Kunne ikke finde kategorien \"%s\"",
    "Sunday" : "Søndag",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sun." : "Søn.",
    "Mon." : "Man.",
    "Tue." : "Tir.",
    "Wed." : "Ons.",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lør.",
    "Su" : "Sø",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "Lø",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Marts",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "En gyldig adgangskode skal angives",
    "Login canceled by app" : "Login annulleret af app",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Appen \"%1$s\" kan ikke installeres, da følgende afhængigheder ikke imødekommes: %2$s",
    "a safe home for all your data" : "et sikkert hjem til alle dine data",
    "File is currently busy, please try again later" : "Filen er i øjeblikket optaget - forsøg igen senere",
    "Cannot download file" : "Kan ikke downloade filen",
    "Application is not enabled" : "Programmet er ikke aktiveret",
    "Authentication error" : "Adgangsfejl",
    "Token expired. Please reload page." : "Adgang er udløbet. Genindlæs siden.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen database driver (sqlite, mysql eller postgresql) er installeret.",
    "Cannot write into \"config\" directory." : "Kan ikke skrive til mappen \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til config mappen. Se %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Men hvis du foretrækker at bibeholde config.php skrivebeskyttet, så sæt parameter \"config_is_read_only\" til true i filen. Se %s",
    "Cannot write into \"apps\" directory." : "Kan ikke skrive til mappen \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dette kan som regel rettes ved at give webserveren skriveadgang til apps-mappen eller slå appstore fra i config-filen.",
    "Cannot create \"data\" directory." : "Kan ikke oprette mappen \"data\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til rod mappen. Se %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Rettigheder kan som regel rettes ved at give webserveren skriveadgang til rodmappen. Se %s.",
    "Your data directory is not writable." : "Data biblioteket er skrivebeskyttet.",
    "Setting locale to %s failed." : "Angivelse af %s for lokalitet mislykkedes.",
    "Please install one of these locales on your system and restart your web server." : "Installér venligst én af disse lokaliteter på dit system, og genstart din webserver.",
    "PHP module %s not installed." : "PHP-modulet %s er ikke installeret.",
    "Please ask your server administrator to install the module." : "Du bedes anmode din serveradministrator om at installere modulet.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-indstillingen \"%s\" er ikke angivet til \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ændring af denne indstilling i php.ini vil tillade Nextcloud at køre igen",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> er angivet til <code>%s</code>, i stedet for den forventede værdi <code>0</code>",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "For at rette dette problem, sæt <code>mbstring.func_overload</code> til <code>0</code> i din php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP er tilsyneladende sat op til at fjerne indlejrede doc-blokke. Dette vil gøre adskillige kerneprogrammer utilgængelige.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette er sansynligvis forårsaget af et accelerator eller cache som Zend OPcache eller eAccelerator",
    "PHP modules have been installed, but they are still listed as missing?" : "Der er installeret PHP-moduler, men de fremstår stadig som fraværende?",
    "Please ask your server administrator to restart the web server." : "Du bedes anmode din serveradministrator om at genstarte webserveren.",
    "The required %s config variable is not configured in the config.php file." : "Den krævede config variabel %s er ikke konfigureret i config.php filen.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Du bedes anmode din serveradministrator om at kontrollere Nextcloud konfigurationen.",
    "Your data directory must be an absolute path." : "Datamappen skal have en absolut sti.",
    "Check the value of \"datadirectory\" in your configuration." : "Tjek værdien for \"datadictionary\" i din konfiguration.",
    "Your data directory is invalid." : "Datamappen er ugyldig.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Du bedes sikre at filen \".ocdata\" befinder sig i roden af din datamappe.",
    "Action \"%s\" not supported or implemented." : "Aktiviteten \"%s\" er ikke understøttet eller implementeret.",
    "Authentication failed, wrong token or provider ID given" : "Kunne ikke validere brugeren",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Anmodningen kunne ikke gennemføres pga. manglende parameter: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" er allerede i brug af cloud federation provider \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Cloud Federation Provider med ID: \"%s\" eksisterer ikke.",
    "Could not obtain lock type %d on \"%s\"." : "Kunne ikke opnå en låsetype %d på \"%s\".",
    "Storage unauthorized. %s" : "Lageret er ikke autoriseret. %s",
    "Storage incomplete configuration. %s" : "Lageret er ikke konfigureret korrekt. %s",
    "Storage connection error. %s" : "Forbindelses fejl til lageret. %s",
    "Storage is temporarily not available" : "Lagerplads er midlertidigt ikke tilgængeligt",
    "Storage connection timeout. %s" : "Lageret svarer ikke. %s",
    "Free prompt" : "Gratis prompt",
    "Runs an arbitrary prompt through the language model." : "Kører en arbitrær prompt gennem sprogmodellen.",
    "Generate headline" : "Generer overskrift",
    "Generates a possible headline for a text." : "Genererer en mulig overskrift til en tekst.",
    "Summarize" : "Opsummer",
    "Summarizes text by reducing its length without losing key information." : "Opsummerer tekst ved at reducere dens længde uden at miste nøgleinformation.",
    "Extract topics" : "Uddrag emner",
    "Extracts topics from a text and outputs them separated by commas." : "Uddrager emner fra en tekst og skriver dem adskilt af kommaer.",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Filerne tilhørende appen %1$s blev ikke erstattet korrekt. Check at versionen er kompatibel med serveren.",
    "404" : "404",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Bruger skal være administrator, underadministrator eller have tildelt specielle rettigheder for at have adgang til denne indstilling",
    "Logged in user must be an admin or sub admin" : "Bruger skal være administrator eller underadministrator",
    "Logged in user must be an admin" : "Brugeren skal være administrator",
    "Full name" : "Fulde navn",
    "Unknown user" : "Ukendt bruger",
    "Enter the database username and name for %s" : "Indtast navn til databasen og brugernavn for %s",
    "Enter the database username for %s" : "Indtast brugernavn til databasen for %s",
    "MySQL username and/or password not valid" : "MySQL brugernavn og/eller kodeord er ikke gyldigt",
    "Oracle username and/or password not valid" : "Oracle brugernavn og/eller kodeord er ikke gyldigt.",
    "PostgreSQL username and/or password not valid" : "PostgreSQL brugernavn og/eller kodeord er ikke gyldigt.",
    "Set an admin username." : "Angiv et admin brugernavn.",
    "Sharing %s failed, because this item is already shared with user %s" : "Deling af %s mislykkedes, fordi dette element allerede er delt med brugeren %s",
    "The username is already being used" : "Brugernavnet er allerede i brug",
    "Could not create user" : "Kunne ikke oprette bruger",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kun følgende tegn kan indgå i et brugernavn: \"a-z\", \"A-Z\", \"0-9\", mellemrum and \"_.@-'\"",
    "A valid username must be provided" : "Et gyldigt brugernavn skal angives",
    "Username contains whitespace at the beginning or at the end" : "Brugernavnet har et mellemrum i starten eller slutningen",
    "Username must not consist of dots only" : "Brugernavnet må ikke bestå af rene prikker/punktummer",
    "Username is invalid because files already exist for this user" : "Brugernavnet er ugyldigt, da der allerede eksisterer filer for denne bruger",
    "User disabled" : "Bruger deaktiveret",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 skal mindst være version 2.7.0. Du har version %s installeret.",
    "To fix this issue update your libxml2 version and restart your web server." : "Opdater din libxml2 version og genstart webserveren for at løse problemet.",
    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 kræves.",
    "Please upgrade your database version." : "Opgradér venligst din databaseversion.",
    "Your data directory is readable by other users." : "Datamappen kan læses af andre brugere.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Tilpas venligst rettigheder til 0770, så mappen ikke fremvises for andre brugere."
},
"nplurals=2; plural=(n != 1);");
